{% load i18n %}
{% load static %}

<div class="d-flex flex-wrap">
    <div class="card flex-grow-1" style="min-width: 350px;">
        <div class="card-body bg-secondary rounded-top">
            <h5 class="card-title text-center">
                <span id="dashboard-info"></span>
            </h5>
            <hr>
            <div>
                <table class="table table-dark table-striped table-hover w-100 d-none" id="manage-dashboard">
                    <tbody>
                        <tr>
                            <td>{% trans "Last Update Wallet:" %}</td>
                            <td class="text-end" id="last_update_wallet"></td>
                        </tr>
                        <tr>
                            <td>{% trans "Last Update Members:" %}</td>
                            <td class="text-end" id="last_update_members"></td>
                        </tr>
                        <tr>
                            <td>{% trans "Last Update Payments:" %}</td>
                            <td class="text-end" id="last_update_payments"></td>
                        </tr>
                        <tr>
                            <td>{% trans "Last Update Payment System:" %}</td>
                            <td class="text-end" id="last_update_paymentsystem"></td>
                        </tr>
                        <tr>
                            <td>{% trans "Tax Amount:" %}</td>
                            <td class="text-end">
                               <i class="fa-solid fa-circle-question fa-fw" data-tooltip-toggle="taxsystem-tooltip" title="{% trans 'Click on the value to edit' %}"></i>
                               <span href="#" id="taxamount" data-url=""></span>
                            </td>
                        </tr>
                        <tr>
                            <td>{% trans "Tax Period:" %}</td>
                            <td class="text-end">
                                <i class="fa-solid fa-circle-question fa-fw" data-tooltip-toggle="taxsystem-tooltip" title="{% trans 'Click on the value to edit' %}"></i>
                                <span href="#" id="period" data-url=""></span>
                            </td>
                        </tr>
                    </tbody>
                </table>
            </div>
        </div>
    </div>
</div>
