{% extends 'taxsystem/base.html' %}
{% load i18n %}
{% load humanize %}
{% load static %}
{% load taxsystem %}

{% block page_title %}
    {{ title }}
{% endblock %}

{% block page_topic %}
    <h1 class="page-header text-center">
        {{ title }}
    </h1>
{% endblock page_topic %}

{% block header_nav_collapse_left %}

    {% include 'taxsystem/partials/menu/navigation.html' %}

{% endblock header_nav_collapse_left %}

{% block header_nav_collapse_right %}

    {% include 'taxsystem/partials/menu/administration.html' %}

{% endblock header_nav_collapse_right %}

{% block taxsystem_block %}
    <div class="card-header bg-primary rounded-top d-flex align-items-center">
        <h3 class="me-3">{% translate "Administration" %}</h3>
    </div>
    <div class="card-body">
        {% include 'taxsystem/partials/view/manage/dashboard.html' %}

        {% include 'taxsystem/partials/view/manage/paymentsystem.html' %}

        {% include 'taxsystem/partials/view/manage/members.html' %}
    </div>
<!-- Tab Session -->
{% include 'taxsystem/modals/confirm.html' with name="PaymentSystem" %}
{% endblock %}

{% block extra_css %}
{% endblock %}

{% block extra_javascript %}
    {% include 'bundles/datatables-js-bs5.html' %}
    {% include "bundles/filterdropdown-js.html" %}
    <!-- load the settings-js.html bundle -->
    {% include 'taxsystem/bundles/settings-js.html' %}
    {% include 'taxsystem/bundles/administration-js.html' %}
{% endblock extra_javascript %}

{% block extra_script %}
{% endblock extra_script %}
