{% extends 'taxsystem/base.html' %}
{% load i18n %}
{% load humanize %}
{% block taxsystem_block %}
    <div class="card-header bg-primary rounded-top">
        <h3>{% translate "Tax System" %}</h3>
    </div>
    <div class="card-body">
        Welcome to Tax System.
    </div>
{% endblock taxsystem_block %}

{% block extra_javascript %}
{% endblock %}

{% block extra_css %}
{% endblock %}

{% block extra_script %}
{% endblock %}
