<form id="approveForm-{{ payment.pk }}" class="text-end" method="post" action="{% url 'taxsystem:approve_payment' corporation_id=corporation_id payment_pk=payment.pk %}">
    {% csrf_token %}
    <input type="hidden" name="payment_pk" value="{{ payment.pk }}">
    <button type="button"
        class="btn btn-success btn-sm btn-square"
        data-bs-toggle="modal"
        data-tooltip-toggle="taxsystem"
        data-bs-target="#modalApprovePaymentContainer"
        data-confirm-text="{{ confirm_text }}"
        data-title="{{ title }}"
        data-form-id="approveForm-{{ payment.pk }}"
        >
        <span class="fas fa-check"></span>
    </button>
</form>
