{% load static %}

<link rel="stylesheet" type="text/css" href="{% static 'taxsystem/css/bootstrap-editable.css' %}">
<script src="{% static 'taxsystem/js/bootstrap-editable.js' %}"></script>
<script src="{% static 'taxsystem/js/manage.js' %}"></script>
