{% extends 'taxsystem/base.html' %}
{% load i18n %}
{% load humanize %}
{% load static %}
{% load taxsystem %}

{% block page_title %}
    {{ title }}
{% endblock %}

{% block page_topic %}
    <h1 class="page-header text-center">
        {{ title }}
    </h1>
{% endblock page_topic %}

{% block header_nav_collapse_left %}

    {% include 'taxsystem/partials/menu/navigation.html' %}

{% endblock header_nav_collapse_left %}

{% block header_nav_collapse_right %}

    {% include 'taxsystem/partials/menu/administration.html' %}

{% endblock header_nav_collapse_right %}

{% block taxsystem_block %}
    <div class="card-header bg-primary rounded-top d-flex align-items-center">
        <h3 class="me-3">{% translate "Payments" %}</h3>
    </div>
    <div class="card-body">
        <div class="card-header bg-primary rounded-top d-flex align-items-center">
        <h3 class="me-3">{% translate "Incoming Payments" %}</h3>
        </div>
        <div class="card-body bg-secondary rounded-bottom">
            <!-- Payments Content-->
            <table class="table table-dark table-striped table-hover w-100 d-none" id="payments">
                <thead>
                    <tr>
                        <th scope="col"></th>
                        <th scope="col">{% translate "Character Name" %}</th>
                        <th scope="col">{% translate "Amount" %}</th>
                        <th scope="col">{% translate "Date" %}</th>
                        <th scope="col">{% translate "Status" %}</th>
                        <th scope="col">{% translate "Approved" %}</th>
                        <th scope="col">{% translate "System" %}</th>
                        <th scope="col">{% translate "Actions" %}</th>
                    </tr>
                </thead>

                <tbody>
                    <!-- Payments -->
                </tbody>
            </table>
        </div>
    </div>
<!-- Tab Session -->
{% include 'taxsystem/modals/confirm.html' with name="ApprovePayment" %}

{% endblock %}

{% block extra_css %}
{% endblock %}

{% block extra_javascript %}
    {% include 'bundles/datatables-js-bs5.html' %}
    {% include "bundles/filterdropdown-js.html" %}
    <!-- load the settings-js.html bundle -->
    {% include 'taxsystem/bundles/settings-js.html' %}
    {% include 'taxsystem/bundles/payments-js.html' %}
{% endblock extra_javascript %}

{% block extra_script %}
{% endblock extra_script %}
