{% load i18n %}
{% load static %}
{% load evelinks %}
{% load humanize %}

<!-- Confirmation Modal -->
<div class="modal fade" id="modal{{ name }}Container" tabindex="-1" role="dialog">
    <div class="modal-dialog modal-dialog-centered" role="document">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title" id="confirmTitle">
                    <!-- Confirmation title will be populated here -->
                </h5>
                <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
            </div>
            <div class="modal-body">
                <span id="confirmText">
                    <!-- Confirmation message will be populated here -->
                </span>
            </div>
            <div class="modal-footer">
                <button type="button" class="btn btn-danger" data-bs-dismiss="modal"><i class="fa-solid fa-hand"></i> {% trans "Cancel" %}</button>
                <button type="button" class="btn btn-success" id="confirmButton"><i class="fa-solid fa-check"></i> {% trans "Confirm" %}</button>
            </div>
        </div>
    </div>
</div>
