<form id="switchUserForm-{{ payment_system.pk }}" class="text-end" method="post" action="{% url 'taxsystem:switch_user' corporation_id=corporation_id user_pk=payment_system.pk %}">
    {% csrf_token %}
    <input type="hidden" name="payment_pk" value="{{ payment_system.pk }}">
    <button type="button"
        class="btn btn-{{ settings.color }} btn-sm btn-square"
        data-bs-toggle="modal"
        data-tooltip-toggle="taxsystem"
        data-bs-target="#modalPaymentSystemContainer"
        data-confirm-text="{{ confirm_text }}"
        data-title="{{ title }}"
        data-form-id="switchUserForm-{{ payment_system.pk }}"
        >
        <span class="{{ settings.icon }}" data-tooltip-toggle="taxsystem-tooltip" title="{{ settings.title }}"></span>
    </button>
</form>
