# Generated by Django 4.2.11 on 2025-02-09 21:00

import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("taxsystem", "0001_initial"),
    ]

    operations = [
        migrations.CreateModel(
            name="FilterDate",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("name", models.CharField(max_length=100)),
                ("description", models.CharField(max_length=255)),
                ("date", models.DateTimeField()),
            ],
            options={
                "verbose_name": "Filter Date",
                "verbose_name_plural": "Filter Dates",
            },
        ),
        migrations.RenameField(
            model_name="owneraudit",
            old_name="last_update_filters",
            new_name="last_update_payment_system",
        ),
        migrations.AddField(
            model_name="members",
            name="joined",
            field=models.DateTimeField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name="members",
            name="logged_off",
            field=models.DateTimeField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name="members",
            name="logon",
            field=models.DateTimeField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name="owneraudit",
            name="tax_amount",
            field=models.DecimalField(
                decimal_places=0,
                default=0,
                help_text="Tax Amount in ISK that is set for the corporation. Max 16 Digits",
                max_digits=16,
                validators=[django.core.validators.MaxValueValidator(9999999999999999)],
            ),
        ),
        migrations.AddField(
            model_name="owneraudit",
            name="tax_period",
            field=models.PositiveIntegerField(
                default=30,
                help_text="Tax Period in days for the corporation. Max 365 days. Default: 30 days",
                validators=[django.core.validators.MaxValueValidator(365)],
            ),
        ),
        migrations.AddField(
            model_name="payments",
            name="notified",
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name="payments",
            name="system",
            field=models.CharField(
                blank=True,
                choices=[("automatic", "Automatic"), ("manual", "Manual")],
                default="",
                max_length=16,
                verbose_name="System",
            ),
        ),
        migrations.AddField(
            model_name="paymentsystem",
            name="last_paid",
            field=models.DateTimeField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name="paymentsystem",
            name="payment_pool",
            field=models.DecimalField(
                decimal_places=0,
                default=0,
                help_text="Payment Pool in ISK that is set for the corporation. Max 16 Digits",
                max_digits=16,
                validators=[
                    django.core.validators.MaxValueValidator(9999999999999999),
                    django.core.validators.MinValueValidator(-9999999999999999),
                ],
            ),
        ),
        migrations.AlterField(
            model_name="payments",
            name="payment_status",
            field=models.CharField(
                blank=True,
                choices=[
                    ("paid", "Paid"),
                    ("pending", "Pending"),
                    ("failed", "Failed"),
                    ("needs_approval", "Needs Approval"),
                ],
                default="",
                max_length=16,
                verbose_name="Status",
            ),
        ),
    ]
